<?php
// Register Custom Post Type for Projects
function create_projects_post_type() {
    $labels = array(
        'name' => __('مشروعات', 'textdomain'),
        'singular_name' => __('مشروع', 'textdomain'),
        'menu_name' => __('مشروعات', 'textdomain'),
        'name_admin_bar' => __('مشروع', 'textdomain'),
        'add_new' => __('إضافة جديد', 'textdomain'),
        'add_new_item' => __('إضافة مشروع جديد', 'textdomain'),
        'new_item' => __('إضافة مشروع', 'textdomain'),
        'edit_item' => __('تعديل مشروع', 'textdomain'),
        'view_item' => __('عرض مشروع', 'textdomain'),
        'all_items' => __('كل المشروعات', 'textdomain'),
        'search_items' => __('ابحث في المشروعات', 'textdomain'),
        'not_found' => __('لا توجد أي مشروعات.', 'textdomain'),
        'not_found_in_trash' => __('لا توجد أي مشروعات في سلة المهملات.', 'textdomain'),
    );

    $args = array(
        'labels' => $labels,
        'public' => true,
        'publicly_queryable' => true,
        'show_ui' => true,
        'show_in_menu' => true,
        'query_var' => true,
        'rewrite' => array('slug' => 'projects'),
        'capability_type' => 'post',
        'has_archive' => true,
        'hierarchical' => false,
        'menu_position' => null,
        'supports' => array('title'),
    );

    register_post_type('projects', $args);
}
add_action('init', 'create_projects_post_type');

// // Add custom meta boxes using OptionsTree
// add_filter('ot_meta_boxes', 'projects_meta_boxes');

// function projects_meta_boxes($meta_boxes) {
//     $projects_meta_box = array(
//         'id' => 'projects_meta_box',
//         'title' => __('Project Details', 'textdomain'),
//         'pages' => array('projects'), // post type
//         'context' => 'normal',
//         'priority' => 'high',
//         'fields' => array(
//             array(
//                 'id' => 'title_ar',
//                 'label' => __('العنوان باللغة العربية', 'textdomain'),
//                 'type' => 'text',
//             ),
//             array(
//                 'id' => 'title_en',
//                 'label' => __('العنوان باللغة الإنجليزية', 'textdomain'),
//                 'type' => 'text',
//             ),
//             array(
//                 'id' => 'type',
//                 'label' => __('النوع', 'textdomain'),
//                 'type' => 'select',
//                 'choices' => array(
//                     array(
//                         'value' => 'new',
//                         'label' => __('جاري العمل به', 'textdomain')
//                     ),
//                     array(
//                         'value' => 'done',
//                         'label' => __('تم الإنتهاء منه', 'textdomain')
//                     ),
//                 ),
//             ),
//         )
//     );

//     if (!is_array($meta_boxes)) {
//         $meta_boxes = array();
//     }

//     $meta_boxes[] = $projects_meta_box;

//     return $meta_boxes;
// }


// Add meta boxes for 'projects' custom post type
add_action('add_meta_boxes', 'add_projects_titles_meta_boxes');

function add_projects_titles_meta_boxes() {
    add_meta_box(
        'projects_meta_box', // Meta box ID
        __('Project Details', 'textdomain'), // Meta box title
        'render_projects_meta_box', // Callback function to render the meta box
        'projects', // Post type
        'normal', // Context (normal, side, advanced)
        'high' // Priority (high, core, default, low)
    );
}

function render_projects_meta_box($post) {
    // Retrieve existing values from the database
    $title_ar = get_post_meta($post->ID, 'title_ar', true);
    $title_en = get_post_meta($post->ID, 'title_en', true);
    $type = get_post_meta($post->ID, 'type', true);

    // Output the fields
    ?>
    <p>
        <label for="title_ar"><?php _e('العنوان باللغة العربية', 'textdomain'); ?></label><br>
        <input type="text" id="title_ar" name="title_ar" value="<?php echo esc_attr($title_ar); ?>">
    </p>
    <p>
        <label for="title_en"><?php _e('العنوان باللغة الإنجليزية', 'textdomain'); ?></label><br>
        <input type="text" id="title_en" name="title_en" value="<?php echo esc_attr($title_en); ?>">
    </p>
    <p>
        <label for="type"><?php _e('النوع', 'textdomain'); ?></label><br>
        <select id="type" name="type">
            <option value="new" <?php selected($type, 'new'); ?>><?php _e('جاري العمل به', 'textdomain'); ?></option>
            <option value="done" <?php selected($type, 'done'); ?>><?php _e('تم الإنتهاء منه', 'textdomain'); ?></option>
        </select>
    </p>
    <style>
        #title_ar, #title_en, #type {
            width: 100%;
            padding: 5px;
        }
    </style>
<?php
}

// Save meta box data
// add_action('save_post', 'save_projects_meta_box_data');

// function save_projects_meta_box_data($post_id) {
//     // Check if our nonce is set.
//     if (!isset($_POST['projects_meta_box_nonce'])) {
//         return;
//     }

//     // Verify that the nonce is valid.
//     if (!wp_verify_nonce($_POST['projects_meta_box_nonce'], 'projects_meta_box_nonce')) {
//         return;
//     }

//     // If this is an autosave, our form has not been submitted, so we don't want to do anything.
//     if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
//         return;
//     }

//     // Check the user's permissions.
//     if (!current_user_can('edit_post', $post_id)) {
//         return;
//     }

//     // Sanitize and save the meta box field values.
//     if (isset($_POST['title_ar'])) {
//         update_post_meta($post_id, 'title_ar', sanitize_text_field($_POST['title_ar']));
//     }
//     if (isset($_POST['title_en'])) {
//         update_post_meta($post_id, 'title_en', sanitize_text_field($_POST['title_en']));
//     }
//     if (isset($_POST['type'])) {
//         update_post_meta($post_id, 'type', sanitize_text_field($_POST['type']));
//     }
// }

// Add meta boxes for text editor fields
function add_projects_meta_boxes() {
    add_meta_box(
        'projects_description_ar',
        __('Description (Arabic)', 'textdomain'),
        'projects_description_ar_callback',
        'projects',
        'normal',
        'high'
    );

    add_meta_box(
        'projects_description_en',
        __('Description (English)', 'textdomain'),
        'projects_description_en_callback',
        'projects',
        'normal',
        'high'
    );
}
add_action('add_meta_boxes', 'add_projects_meta_boxes');

function projects_description_ar_callback($post) {
    $description_ar = get_post_meta($post->ID, 'description_ar', true);
    wp_editor($description_ar, 'description_ar', array('textarea_rows' => 5));
}

function projects_description_en_callback($post) {
    $description_en = get_post_meta($post->ID, 'description_en', true);
    wp_editor($description_en, 'description_en', array('textarea_rows' => 5));
}

// Save meta box data
function save_projects_meta_boxes($post_id) {

    // Sanitize and save the meta box field values.
    if (isset($_POST['title_ar'])) {
        update_post_meta($post_id, 'title_ar', sanitize_text_field($_POST['title_ar']));
    }
    if (isset($_POST['title_en'])) {
        update_post_meta($post_id, 'title_en', sanitize_text_field($_POST['title_en']));
    }
    if (isset($_POST['type'])) {
        update_post_meta($post_id, 'type', sanitize_text_field($_POST['type']));
    }



    if (array_key_exists('description_ar', $_POST)) {
        update_post_meta($post_id, 'description_ar', $_POST['description_ar']);
    }

    if (array_key_exists('description_en', $_POST)) {
        update_post_meta($post_id, 'description_en', $_POST['description_en']);
    }
}
add_action('save_post', 'save_projects_meta_boxes');
?>
