<?php

// Define custom walker class for language-aware navigation menu
class Custom_Language_Nav_Walker extends Walker_Nav_Menu {
    // Extend start_el method to include custom language labels
    function start_el(&$output, $item, $depth = 0, $args = null, $id = 0) {
        $custom_label_en = get_post_meta($item->ID, '_custom_label_en', true);
        
        // Use custom label if available, otherwise use default label
        $item->title = !empty($custom_label_en) ? $custom_label_en : $item->title;
        
        parent::start_el($output, $item, $depth, $args, $id);
    }
}


// Add custom meta box for menu item
function add_custom_menu_item_fields($item_id, $item, $depth, $args) {
    // Add a nonce field so we can check for it later
    wp_nonce_field('custom_menu_item_fields', 'custom_menu_item_nonce');

    // Get the current value of the custom field
    $custom_label_en = get_post_meta($item_id, '_custom_label_en', true);

    // Output the custom field HTML
?>
    <p class="field-custom-description description description-wide">
        <label for="edit-menu-item-custom-label-en-<?php echo $item_id; ?>"><?php _e('الاسم باللغة الإنجليزية:'); ?><br />
            <input type="text" id="edit-menu-item-custom-label-en-<?php echo $item_id; ?>" class="widefat code edit-menu-item-custom-label" name="menu-item-custom-label-en[<?php echo $item_id; ?>]" value="<?php echo esc_attr($custom_label_en); ?>" />
        </label>
    </p>
<?php
    }
add_action('wp_nav_menu_item_custom_fields', 'add_custom_menu_item_fields', 10, 4);

// Save custom menu item fields
function save_custom_menu_item_fields($menu_id, $menu_item_db_id, $args) {
    // Check if nonce is set
    if (!isset($_POST['custom_menu_item_nonce']) || !wp_verify_nonce($_POST['custom_menu_item_nonce'], 'custom_menu_item_fields')) {
        return $menu_id;
    }

    // Check if current user has permissions to edit menu
    if (!current_user_can('edit_post', $menu_item_db_id)) {
        return $menu_id;
    }

    // Save custom label field
    if (isset($_POST['menu-item-custom-label-en'][$menu_item_db_id])) {
        update_post_meta($menu_item_db_id, '_custom_label_en', sanitize_text_field($_POST['menu-item-custom-label-en'][$menu_item_db_id]));
    }
}
add_action('wp_update_nav_menu_item', 'save_custom_menu_item_fields', 10, 3);
