<?php
// Add meta box for content_ar field
function add_content_ar_meta_box() {
    add_meta_box(
        'content_ar_meta_box', // Meta box ID
        __('المحتوى بالغة العربية', 'text-domain'), // Meta box title
        'render_content_ar_meta_box', // Callback function to render the meta box
        'page', // Post type where the meta box will be displayed
        'normal', // Context: 'normal', 'advanced', or 'side'
        'high' // Priority: 'high', 'core', 'default', or 'low'
    );
}
add_action('add_meta_boxes', 'add_content_ar_meta_box');

// Render content_ar meta box
function render_content_ar_meta_box($post) {
    // Retrieve existing values for content_ar and title_ar fields
    $content_ar = get_post_meta($post->ID, 'content_ar', true);
    $title_ar = get_post_meta($post->ID, 'title_ar', true);

    // Add nonce field for security
    wp_nonce_field('save_content_ar_meta', 'content_ar_meta_nonce');
    ?>
    <p>
        <label for="title_ar"><?php _e('العنوان بالعربية:', 'text-domain'); ?></label>
        <br />
        <input type="text" id="title_ar" name="title_ar" value="<?php echo esc_attr($title_ar); ?>" style="width: 100%;" />
    </p>
    <?php
    // Output the rich text editor for content_ar field
    wp_editor($content_ar, 'content_ar_editor', array(
        'textarea_name' => 'content_ar', // Name attribute of the textarea
        'media_buttons' => false, // Disable media buttons
        'teeny' => true, // Use the minimal editor
        'textarea_rows' => 10, // Number of rows
    ));
}

// Save content_ar and title_ar fields
function save_content_ar_meta($post_id) {
    // Check if nonce is set and valid
    if (!isset($_POST['content_ar_meta_nonce']) || !wp_verify_nonce($_POST['content_ar_meta_nonce'], 'save_content_ar_meta')) {
        return;
    }

    // Check if this is an autosave
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }

    // Check if the user has permissions to save data
    if (!current_user_can('edit_post', $post_id)) {
        return;
    }

    // Save the content_ar field
    if (isset($_POST['content_ar'])) {
        update_post_meta($post_id, 'content_ar', $_POST['content_ar']);
    }

    // Save the title_ar field
    if (isset($_POST['title_ar'])) {
        update_post_meta($post_id, 'title_ar', sanitize_text_field($_POST['title_ar']));
    }
}
add_action('save_post', 'save_content_ar_meta');
